/**
 * Hlavní semestrální práce z KIV/VSP
 * (c) 2006 - 2007 Ivan Habernal
 * e-mail: habernal@students.zcu.cz
 */
package cz.habi.vsp.sem.distribution;

/**
 * This class implements the erlang distribution with shape = 2.
 * 
 * @author habi
 * 
 */
public class ErlangDistribution implements Distribution {

	private double lambda;

	private static final int SHAPE = 2;

	/**
	 * Creates a new instance of ErlangDistribution with the lambda parameter
	 * 
	 * @param lambda the lambda
	 * @throws IllegalArgumentException
	 *             if the lambda is negative
	 */
	public ErlangDistribution(double lambda) throws IllegalArgumentException {
		if (lambda <= 0) {
			throw new IllegalArgumentException("Lambda must be greater than 0");
		}
		this.lambda = lambda;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see cz.habi.vsp.sem1.Distribution#getMean()
	 */
	public double getMean() {
		return ((double) SHAPE) / lambda;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see cz.habi.vsp.sem1.Distribution#getRandomValue(double)
	 */
	public double getRandomValue() {
		double uniformDistributionRandomValue = Math.random();
		double firstValue = -Math.log(uniformDistributionRandomValue) * (1d / lambda);

		uniformDistributionRandomValue = Math.random();
		double secondValue = -Math.log(uniformDistributionRandomValue) * (1d / lambda);

		return firstValue + secondValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see cz.habi.vsp.sem1.Distribution#getVariance()
	 */
	public double getVariance() {
		return ((double) SHAPE) / (lambda * lambda);
	}
}
