/**
 * Hlavní semestrální práce z KIV/VSP
 * (c) 2006 - 2007 Ivan Habernal
 * e-mail: habernal@students.zcu.cz
 */
package cz.habi.vsp.sem.network;

/**
 * This class represents a sigle target from the {@link FlowCrossing}. Each
 * target has its propability, that the request continues to the certain
 * {@link RequestAcceptor}.
 * 
 * @author habi
 * 
 */
public class CrossingTarget {

	private double propability;

	private RequestAcceptor requestAcceptor;

	/**
	 * Creates a new instance of CrossingTarget
	 * 
	 * @param probability
	 *            propability of this target
	 * @param requestAcceptor
	 *            the next request acceptor in the queue
	 * @throws IllegalArgumentException
	 *             if the probability is not in (0 - 1) or if the
	 *             requestAcceptor is null
	 */
	public CrossingTarget(double probability, RequestAcceptor requestAcceptor) throws IllegalArgumentException {
		if (probability < 0 || probability > 1) {
			throw new IllegalArgumentException("Wrong probability: " + probability);
		}

		if (requestAcceptor == null) {
			throw new IllegalArgumentException("Request acceptor is null");
		}
		this.propability = probability;
		this.requestAcceptor = requestAcceptor;
	}

	/**
	 * Returs the probability
	 * 
	 * @return probability
	 */
	public double getPropability() {
		return propability;
	}

	/**
	 * Returns the next requestAcceptor
	 * 
	 * @return requestAcceptor
	 */
	public RequestAcceptor getRequestAcceptor() {
		return requestAcceptor;
	}
}
