/**
 * Hlavní semestrální práce z KIV/VSP
 * (c) 2006 - 2007 Ivan Habernal
 * e-mail: habernal@students.zcu.cz
 */
package cz.habi.vsp.sem.network;

import java.math.BigDecimal;
import java.math.MathContext;

/**
 * This class provides a simple set of statistic methods, such are mean and
 * deviation. It uses the continuous calculation and the inner implementation
 * uses {@link BigDecimal} for better accuracy.
 * 
 * @author habi
 * 
 */
public class Statistics {

	private int count = 0;

	private BigDecimal mean = BigDecimal.ZERO;

	private BigDecimal squaredMean = BigDecimal.ZERO;

	private static final MathContext MC = new MathContext(50);

	/**
	 * Adds a value to the statistic set.
	 * 
	 * @param value
	 *            value
	 */
	synchronized public void addValue(double value) {
		count++;

		mean = mean.add(BigDecimal.valueOf(value).subtract(mean).divide(BigDecimal.valueOf(count), MC));

		squaredMean = squaredMean.add(BigDecimal.valueOf(value).pow(2).subtract(squaredMean).divide(BigDecimal.valueOf(count), MC));
	}

	/**
	 * Returns a count of all values.
	 * 
	 * @return Count of values
	 */
	public int getCount() {
		return count;
	}

	/**
	 * Returns the arithmetic mean of all values.
	 * 
	 * @return arithmetic mean
	 */
	public double getMean() {
		return mean.doubleValue();
	}

	/**
	 * Returns a deviation of all values.
	 * 
	 * @return deviation
	 */
	public double getDeviation() {
		BigDecimal mm = mean.pow(2);

		double e = squaredMean.subtract(mm).doubleValue();
		if (e >= 0) {
			return Math.sqrt(e);
		} else {
			return 0;
		}
	}
}
